@@ -2,7 +2,7 @@ package Net::BitTorrent::Peer;
 {
     use Moose;
     use Moose::Util::TypeConstraints;
-    use 5.012;
+    use 5.010.000;
     use lib '../../../lib';
     use Net::BitTorrent::Types qw[:torrent];
     use Net::BitTorrent::Protocol::BEP03::Packets
@@ -938,7 +938,7 @@ L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/u
 Neither this module nor the L<Author|/Author> is affiliated with BitTorrent,
 Inc.
 
-=for rcs $Id: Peer.pm 62b27d0 2010-09-05 04:22:11Z sanko@cpan.org $
+=for rcs $Id: Peer.pm d9b2c6b 2010-09-12 03:05:02Z sanko@cpan.org $
 
 
 =cut
